@@ -1,12 +1,14 @@
 package Perinci::Sub::ConvertArgs::Argv;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use Data::Sah::Util::Type qw(is_simple);
+
 use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(convert_args_to_argv);
@@ -85,8 +87,12 @@ sub convert_args_to_argv {
     }
 
     for (sort keys %iargs) {
-        my $is_bool = $args_prop->{$_}{schema} &&
-            $args_prop->{$_}{schema}[0] eq 'bool';
+        my $sch = $args_prop->{$_}{schema};
+        my $is_bool = $sch && $sch->[0] eq 'bool';
+        my $is_array_of_simple = $sch && $sch->[0] eq 'array' &&
+            $sch->[1]{of} && is_simple($sch->[1]{of});
+        my $can_be_comma_separated = $is_array_of_simple &&
+            $sch->[1]{of}[0] =~ /\A(int|float)\z/; # XXX as well as other simple types that cannot contain commas
         my $opt = $_; $opt =~ s/_/-/g;
         my $dashopt = length($opt) > 1 ? "--$opt" : "-$opt";
         if ($is_bool) {
@@ -95,6 +101,12 @@ sub convert_args_to_argv {
             } else {
                 push @argv, "--no$opt";
             }
+        } elsif ($can_be_comma_separated) {
+            push @argv, "$dashopt", join(",", @{ $iargs{$_} });
+        } elsif ($is_array_of_simple) {
+            for (@{ $iargs{$_} }) {
+                push @argv, "$dashopt", $_;
+            }
         } else {
             if (ref $iargs{$_}) {
                 push @argv, "$dashopt-json", _encode($iargs{$_});
@@ -121,7 +133,7 @@ Perinci::Sub::ConvertArgs::Argv - Convert hash arguments to command-line options
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2015-09-03.
+This document describes version 0.06 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
@@ -150,6 +162,8 @@ C<Perinci::Sub::GetArgs::Argv::get_args_from_argv>.
 Note: currently the function expects schemas in metadata to be normalized
 already.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
